@@ -1,6 +1,6 @@
 /*
  * lists.c -- Functions to implement a double linked list
- * XBoard $Id: lists.c,v 1.2 1995/07/28 05:23:42 mann Exp $
+ * XBoard $Id: lists.c,v 1.3 1998/05/24 05:14:31 mann Exp $
  *
  * Copyright 1995 Free Software Foundation, Inc.
  *
@@ -24,7 +24,7 @@
  * way.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <stdio.h>
 #if STDC_HEADERS
