@@ -1,6 +1,6 @@
 /*
  * moves.h - Move generation and checking
- * $Id: moves.h,v 1.5 1995/06/19 21:43:28 mann Exp $
+ * $Id: moves.h,v 1.6 1997/04/06 00:57:10 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -66,6 +66,7 @@ typedef void (*MoveCallback) P((Board board, int flags, ChessMove kind,
 #define F_BLACK_QCASTLE_OK 16
 #define F_ALL_CASTLE_OK (F_WHITE_KCASTLE_OK | F_WHITE_QCASTLE_OK | \
 			 F_BLACK_KCASTLE_OK | F_BLACK_QCASTLE_OK)
+#define F_IGNORE_CHECK 32
 
 /* Special epfile values */
 #define EP_NONE -1
@@ -82,10 +83,11 @@ typedef void (*MoveCallback) P((Board board, int flags, ChessMove kind,
 extern void GenPseudoLegal P((Board board, int flags, int epfile,
 			      MoveCallback callback, VOIDSTAR closure));
 
-/* Like GenPseudoLegal, but include castling moves and omit moves that
-   would leave the king in check.  The CASTLE_OK flags are true if
-   castling is not yet ruled out by a move of the king or rook.
-   Return TRUE if the player on move is currently in check.
+/* Like GenPseudoLegal, but include castling moves and (unless 
+   F_IGNORE_CHECK is set in the flags) omit moves that would leave the
+   king in check.  The CASTLE_OK flags are true if castling is not yet
+   ruled out by a move of the king or rook.  Return TRUE if the player
+   on move is currently in check and F_IGNORE_CHECK is not set.
 */
 extern int GenLegal P((Board board, int flags, int epfile,
 			MoveCallback callback, VOIDSTAR closure));
