@@ -1,6 +1,6 @@
 /*
  * pgntags.c -- Functions to manage PGN tags
- * XBoard $Id: pgntags.c,v 1.8 1996/12/20 00:28:13 mann Exp $
+ * XBoard $Id: pgntags.c,v 1.10 1999/02/25 22:23:26 mann Exp $
  *
  * Copyright 1995 Free Software Foundation, Inc.
  *
@@ -24,7 +24,7 @@
  * way.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <stdio.h>
 #include <errno.h>
@@ -110,6 +110,10 @@ int ParsePGNTag(tag, gameInfo)
     } else if (StrCaseCmp(name, "SetUp") == 0) {
 	/* ignore on input; presence of FEN governs */
 	success = TRUE;
+    } else if (StrCaseCmp(name, "Variant") == 0) {
+        /* xboard-defined extension */
+        gameInfo->variant = StringToVariant(value);
+	success = TRUE;
     } else {
 	if (gameInfo->extraTags == NULL) {
 	    oldTags = "";
@@ -175,6 +179,10 @@ static char *PGNTagsStatic(gameInfo)
 	sprintf(buf1, "[TimeControl \"%s\"]\n", gameInfo->timeControl);
 	strcat(buf, buf1);
     }
+    if (gameInfo->variant != VariantNormal) {
+        sprintf(buf1, "[Variant \"%s\"]\n", VariantName(gameInfo->variant));
+	strcat(buf, buf1);
+    }
     if (gameInfo->extraTags != NULL) {
 	strcat(buf, gameInfo->extraTags);
     }
